@@ -8,13 +8,18 @@
 # along with this program; if not, write to the Free Software Foundation, Inc., 51
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# (c) 2016 Valentin Samir
+# (c) 2016-2020 Valentin Samir
 """Clean old trickets management command"""
 from django.core.management.base import BaseCommand
-from django.utils.translation import ugettext_lazy as _
 
 from ... import models
 
+import sys
+if sys.version_info < (3, ):
+    from django.utils.translation import ugettext_lazy as _
+else:
+    from django.utils.translation import gettext_lazy as _
+
 
 class Command(BaseCommand):
     """Clean old trickets"""
