@@ -8,7 +8,7 @@
 # along with this program; if not, write to the Free Software Foundation, Inc., 51
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# (c) 2015-2016 Valentin Samir
+# (c) 2015-2025 Valentin Samir
 """views for the app"""
 from .default_settings import settings, SessionStore
 
@@ -37,17 +37,23 @@ except ImportError:
     from django.core.urlresolvers import reverse
 
 import re
+import base64
 import logging
 import pprint
 import requests
 from lxml import etree
 from datetime import timedelta
 
+if settings.CAS_AUTH_GSSAPI_ENABLE:
+    try:
+        import gssapi
+    except ImportError:
+        raise RuntimeError("Please install gssapi before using the Kerberos auth")
+
 import cas_server.utils as utils
-import cas_server.forms as forms
 import cas_server.models as models
 
-from .utils import json_response
+from .utils import json_response, import_attr
 from .models import Ticket, ServiceTicket, ProxyTicket, ProxyGrantingTicket
 from .models import ServicePattern, FederatedIendityProvider, FederatedUser
 from .federate import CASFederateValidateUser
@@ -302,7 +308,7 @@ class FederateAuth(CsrfExemptView):
                     .process_view(request, None, (), {})
             if reason is not None:  # pragma: no cover (csrf checks are disabled during tests)
                 return reason  # Failed the test, stop here.
-            form = forms.FederateSelect(request.POST)
+            form = import_attr(settings.CAS_FEDERATE_SELECT_FORM)(request.POST)
             if form.is_valid():
                 params = utils.copy_params(
                     request.POST,
@@ -523,14 +529,7 @@ class LoginView(View, LogoutMixin):
                 _(u"Invalid login ticket, please try to log in again")
             )
         elif ret == self.USER_LOGIN_OK:
-            # On successful login, update the :class:`models.User<cas_server.models.User>` ``date``
-            # attribute by saving it. (``auto_now=True``)
-            self.user = models.User.objects.get_or_create(
-                username=self.request.session['username'],
-                session_key=self.request.session.session_key
-            )[0]
-            self.user.last_login = timezone.now()
-            self.user.save()
+            pass
         elif ret == self.USER_LOGIN_FAILURE:  # bad user login
             if settings.CAS_FEDERATE:
                 self.ticket = None
@@ -559,6 +558,25 @@ class LoginView(View, LogoutMixin):
             response.delete_cookie("warn")
         return response
 
+    def user_login(self, username, warn, warned=True):
+        self.request.session.set_expiry(0)
+        self.request.session["username"] = username
+        self.request.session["warn"] = warn
+        self.request.session["authenticated"] = True
+        self.renewed = True
+        self.warned = warned
+
+        # On successful login, update the :class:`models.User<cas_server.models.User>` ``date``
+        # attribute by saving it. (``auto_now=True``)
+        self.user = models.User.objects.get_or_create(
+            username=self.request.session['username'],
+            session_key=self.request.session.session_key
+        )[0]
+        self.user.last_login = timezone.now()
+        self.user.save()
+
+        logger.info("User %s successfully authenticated" % username)
+
     def process_post(self):
         """
             Analyse the POST request:
@@ -584,13 +602,11 @@ class LoginView(View, LogoutMixin):
             # authentication request receive, initialize the form to use
             self.init_form(self.request.POST)
             if self.form.is_valid():
-                self.request.session.set_expiry(0)
-                self.request.session["username"] = self.form.cleaned_data['username']
-                self.request.session["warn"] = True if self.form.cleaned_data.get("warn") else False
-                self.request.session["authenticated"] = True
-                self.renewed = True
-                self.warned = True
-                logger.info("User %s successfully authenticated" % self.request.session["username"])
+                self.user_login(
+                    self.form.cleaned_data['username'],
+                    True if self.form.cleaned_data.get("warn") else False,
+                    warned=True
+                )
                 return self.USER_LOGIN_OK
             else:
                 logger.warning("A login attempt failed")
@@ -622,6 +638,57 @@ class LoginView(View, LogoutMixin):
             if self.ticket:
                 del request.session["federate_ticket"]
 
+    def gssapi_auth(self):
+        self.request.session['GSSAPI'] = False
+        # read http header Authorization
+        auth_header = self.request.META.get('HTTP_AUTHORIZATION', None)
+        # if header is missing or do not match SPNEGO, start GSSAPI auth
+        if auth_header is None or not auth_header.startswith('Negotiate '):
+            # call the GET/POST common part
+            response = self.common()
+            response.status_code = 401
+            # demande la négo GSSAPI
+            response['WWW-Authenticate'] = 'Negotiate '
+            return response
+        else:
+            try:
+                try:
+                    server_creds = gssapi.Credentials(
+                        usage='accept',
+                        name=gssapi.Name(settings.CAS_AUTH_GSSAPI_SERVICENAME)
+                    )
+                except gssapi.exceptions.GSSError as error:
+                    logger.error("Fail to create GSSAPI credentials objects: %s" % (error,))
+                    server_creds = None
+                # decode and check auth header
+                tok = base64.b64decode(auth_header[len('Negotiate '):])
+                ctx = gssapi.SecurityContext(creds=server_creds, usage='accept')
+                server_tok = ctx.step(tok)
+                b64tok = base64.b64encode(server_tok)
+                # If GSSAPI auth is successful
+                if ctx.complete:
+                    # retreive the user username (remove the realm part)
+                    username = str(ctx.initiator_name).split('@', 1)[0]
+                    self.user_login(
+                        username,
+                        warn=False,
+                        warned=False
+                    )
+                    self.request.session['GSSAPI'] = True
+                    # call the GET/POST common part
+                    return self.common()
+                # sinon, ou la négo continue, ou l'utilisateur peut utiliser le form login/pass
+                else:
+                    # call the GET/POST common part
+                    response = self.common()
+                    response.status_code = 401
+                    response['WWW-Authenticate'] = 'Negotiate ' + b64tok.decode('ascii')
+                    return response
+            except gssapi.exceptions.GSSError as error:
+                logger.error("Error during GSSAPI handshake: %s" % (error,))
+                # call the GET/POST common part
+                return self.common()
+
     def get(self, request, *args, **kwargs):
         """
             method called on GET request on this view
@@ -632,8 +699,15 @@ class LoginView(View, LogoutMixin):
         self.init_get(request)
         # process the GET request
         self.process_get()
-        # call the GET/POST common part
-        return self.common()
+        if (
+            not settings.CAS_FEDERATE and
+            settings.CAS_AUTH_GSSAPI_ENABLE and
+            not request.session.get("authenticated")
+        ):
+            return self.gssapi_auth()
+        else:
+            # call the GET/POST common part
+            return self.common()
 
     def process_get(self):
         """
@@ -677,14 +751,16 @@ class LoginView(View, LogoutMixin):
                 form_initial['username'] = self.username
                 form_initial['password'] = self.ticket
                 form_initial['ticket'] = self.ticket
-                self.form = forms.FederateUserCredential(
+                self.form = import_attr(settings.CAS_FEDERATE_USER_CREDENTIAL_FORM)(
                     values,
                     initial=form_initial
                 )
             else:
-                self.form = forms.FederateSelect(values, initial=form_initial)
+                self.form = import_attr(
+                    settings.CAS_FEDERATE_SELECT_FORM
+                )(values, initial=form_initial)
         else:
-            self.form = forms.UserCredential(
+            self.form = import_attr(settings.CAS_USER_CREDENTIAL_FORM)(
                 values,
                 initial=form_initial
             )
@@ -720,7 +796,7 @@ class LoginView(View, LogoutMixin):
                     data = {"status": "error", "detail": "confirmation needed"}
                     return json_response(self.request, data)
                 else:
-                    warn_form = forms.WarnForm(initial={
+                    warn_form = import_attr(settings.CAS_WARN_FORM)(initial={
                         'service': self.service,
                         'renew': self.renew,
                         'gateway': self.gateway,
@@ -999,7 +1075,7 @@ class Auth(CsrfExemptView):
             return HttpResponse(u"no\n", content_type="text/plain; charset=utf-8")
         if not username or not password or not service:
             return HttpResponse(u"no\n", content_type="text/plain; charset=utf-8")
-        form = forms.UserCredential(
+        form = import_attr(settings.CAS_USER_CREDENTIAL_FORM)(
             request.POST,
             initial={
                 'service': service,
